"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.KeycloakUserInfo = void 0;
const common_1 = require("@nestjs/common");
const microservices_1 = require("@nestjs/microservices");
const grpc_js_1 = require("@grpc/grpc-js");
exports.KeycloakUserInfo = (0, common_1.createParamDecorator)((data, ctx) => {
    const metadata = ctx.switchToRpc().getContext();
    const userinfoAsString = metadata.get('userinfo')[0];
    if (!userinfoAsString) {
        console.error('Could not load Keycloak UserInfo. Is the Protected Guard in place?');
        throw new microservices_1.RpcException({
            code: grpc_js_1.status.INTERNAL,
            message: 'An error occurred',
        });
    }
    let keycloakUserInfo;
    try {
        keycloakUserInfo = JSON.parse(userinfoAsString);
    }
    catch (e) {
        console.error('Unknown error occurred while trying to parse Keycloak UserInfo');
    }
    if (!keycloakUserInfo.userId) {
        console.error('User Attribute has not been mapped to the userinfo endpoint. Failing request.');
        throw new microservices_1.RpcException({
            code: grpc_js_1.status.INTERNAL,
            message: 'An internal error occurred. Please contact support',
        });
    }
    return keycloakUserInfo;
});
