"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.RoleGuard = void 0;
const common_1 = require("@nestjs/common");
const core_1 = require("@nestjs/core");
const microservices_1 = require("@nestjs/microservices");
const grpc_js_1 = require("@grpc/grpc-js");
const keycloak_service_1 = require("../services/keycloak.service");
const role_decorator_1 = require("../decorators/role.decorator");
const authorization_exception_1 = require("../exceptions/authorization.exception");
let RoleGuard = class RoleGuard {
    constructor(keycloakAuthService) {
        this.keycloakAuthService = keycloakAuthService;
        this.reflector = new core_1.Reflector(); // because the nestjs ioc refused to resolve it as needed here, and this does the same job
    }
    canActivate(context) {
        const roleToCheck = this.reflector.get(role_decorator_1.META_ROLE, context.getHandler());
        if (!roleToCheck) {
            return true;
        }
        const token = context
            .switchToRpc()
            .getContext()
            .get('token')[0];
        if (!token) {
            console.error('Token not found. Make sure the Protected guard is activated before the Role guard');
            throw new microservices_1.RpcException({
                code: grpc_js_1.status.PERMISSION_DENIED,
                message: 'You are not authorized to perform this action',
            });
        }
        // passing the full header instead of just the token because the keycloak library expects everything
        return this.evaluate(token, roleToCheck);
    }
    evaluate(token, role) {
        return __awaiter(this, void 0, void 0, function* () {
            let hasRole;
            try {
                hasRole = yield this.keycloakAuthService.userHasRole(token, role);
            }
            catch (e) {
                console.error('Error checking user role: ', e.message);
            }
            if (!hasRole) {
                throw new authorization_exception_1.AuthorizationException();
            }
            return true;
        });
    }
};
RoleGuard = __decorate([
    (0, common_1.Injectable)(),
    __metadata("design:paramtypes", [keycloak_service_1.KeycloakAuthService])
], RoleGuard);
exports.RoleGuard = RoleGuard;
