"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.KeycloakAuthService = void 0;
const common_1 = require("@nestjs/common");
const config_1 = require("@nestjs/config");
const keycloak_connect_1 = __importDefault(require("keycloak-connect"));
const microservices_1 = require("@nestjs/microservices");
const grpc_js_1 = require("@grpc/grpc-js");
let KeycloakAuthService = class KeycloakAuthService {
    constructor(configService) {
        this.configService = configService;
        const keycloakServerUrl = this.configService.get('KEYCLOAK_BASE_URL');
        const realm = this.configService.get('KEYCLOAK_REALM');
        const clientId = this.configService.get('KEYCLOAK_CLIENT_ID');
        const clientSecret = this.configService.get('KEYCLOAK_CLIENT_SECRET');
        const keycloakConfigPartial = {
            realm,
            'auth-server-url': keycloakServerUrl,
            'bearer-only': false,
            'confidential-port': 0,
            resource: clientId,
            'ssl-required': 'external',
        };
        // because some important fields are not included in the keycloak config type
        const kcConfig = Object.assign(Object.assign({}, keycloakConfigPartial), { secret: clientSecret, verifyTokenAudience: true });
        this.keycloak = new keycloak_connect_1.default({}, kcConfig);
        this.keycloak.redirectToLogin = () => false;
        // eslint-disable-next-line @typescript-eslint/ban-ts-comment
        // @ts-ignore
        this.keycloak.accessDenied = (req, res, next) => {
            throw new microservices_1.RpcException({
                code: grpc_js_1.status.UNAUTHENTICATED,
                message: 'Unauthenticated',
            });
        };
    }
    isAuthenticated(authorizationHeader) {
        return __awaiter(this, void 0, void 0, function* () {
            const token = authorizationHeader.substring(7);
            return yield this.keycloak.grantManager.validateAccessToken(token);
        });
    }
    userHasRole(token, role) {
        return __awaiter(this, void 0, void 0, function* () {
            const tokenObject = yield this.keycloak.grantManager.createGrant({
                access_token: token,
            });
            return tokenObject.access_token.hasRole(role);
        });
    }
    userInfo(token) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.keycloak.grantManager.userInfo(token);
        });
    }
};
KeycloakAuthService = __decorate([
    (0, common_1.Injectable)(),
    __metadata("design:paramtypes", [config_1.ConfigService])
], KeycloakAuthService);
exports.KeycloakAuthService = KeycloakAuthService;
